@@ -8,17 +8,18 @@
 
 #include <vdr/menu.h>
 #include <vdr/remote.h>
+#include <vdr/menu.h>
 #include "femoncfg.h"
 #include "femonreceiver.h"
 #include "femonosd.h"
 #include "femonservice.h"
 #include "femontools.h"
 
-#if defined(APIVERSNUM) && APIVERSNUM < 10508
-#error "VDR-1.5.8 API version or greater is required!"
+#if defined(APIVERSNUM) && APIVERSNUM < 10600
+#error "VDR-1.6.0 API version or greater is required!"
 #endif
 
-static const char VERSION[]       = "1.2.2";
+static const char VERSION[]       = "1.6.1";
 static const char DESCRIPTION[]   = trNOOP("DVB Signal Information Monitor (OSD)");
 static const char MAINMENUENTRY[] = trNOOP("Signal Information");
 
@@ -97,8 +98,8 @@ cOsdObject *cPluginFemon::MainMenuAction(void)
 {
   // Perform the action when selected from the main VDR menu.
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
-  if (cReplayControl::NowReplaying())
-     Skins.Message(mtInfo, tr("Femon not available while replaying"));
+  if (cReplayControl::NowReplaying() || (Channels.Count() <= 0))
+     Skins.Message(mtInfo, tr("Femon not available"));
   else
      return cFemonOsd::Instance(true);
   return NULL;
@@ -108,6 +109,7 @@ bool cPluginFemon::SetupParse(const char *Name, const char *Value)
 {
   // Parse your own setup parameters and store their values.
   if      (!strcasecmp(Name, "HideMenu"))       femonConfig.hidemenu       = atoi(Value);
+  else if (!strcasecmp(Name, "UseSingleArea"))  femonConfig.usesinglearea  = atoi(Value);
   else if (!strcasecmp(Name, "DisplayMode"))    femonConfig.displaymode    = atoi(Value);
   else if (!strcasecmp(Name, "Position"))       femonConfig.position       = atoi(Value);
   else if (!strcasecmp(Name, "OSDHeight"))      femonConfig.osdheight      = atoi(Value);
@@ -132,18 +134,20 @@ bool cPluginFemon::SetupParse(const char *Name, const char *Value)
 
 bool cPluginFemon::Service(const char *Id, void *Data)
 {
-  if ((strcmp(Id,"FemonService-v1.0") == 0) && Data) {
-     FemonService_v1_0 *data = (FemonService_v1_0*)Data;
-     int ndx = cDevice::ActualDevice()->CardIndex();
-     data->fe_name = getFrontendName(ndx);
-     data->fe_status = getFrontendStatus(ndx);
-     data->fe_snr = getSNR(ndx);
-     data->fe_signal = getSignal(ndx);
-     data->fe_ber = getBER(ndx);
-     data->fe_unc = getUNC(ndx);
-     data->video_bitrate = cFemonOsd::Instance() ? cFemonOsd::Instance()->GetVideoBitrate() : 0.0;
-     data->audio_bitrate = cFemonOsd::Instance() ? cFemonOsd::Instance()->GetAudioBitrate() : 0.0;
-     data->dolby_bitrate = cFemonOsd::Instance() ? cFemonOsd::Instance()->GetDolbyBitrate() : 0.0;
+  if (strcmp(Id,"FemonService-v1.0") == 0) {
+     if (Data) {
+        FemonService_v1_0 *data = (FemonService_v1_0*)Data;
+        int ndx = cDevice::ActualDevice()->CardIndex();
+        data->fe_name = getFrontendName(ndx);
+        data->fe_status = getFrontendStatus(ndx);
+        data->fe_snr = getSNR(ndx);
+        data->fe_signal = getSignal(ndx);
+        data->fe_ber = getBER(ndx);
+        data->fe_unc = getUNC(ndx);
+        data->video_bitrate = cFemonOsd::Instance() ? cFemonOsd::Instance()->GetVideoBitrate() : 0.0;
+        data->audio_bitrate = cFemonOsd::Instance() ? cFemonOsd::Instance()->GetAudioBitrate() : 0.0;
+        data->dolby_bitrate = cFemonOsd::Instance() ? cFemonOsd::Instance()->GetDolbyBitrate() : 0.0;
+        }
      return true;
      }
 
@@ -264,7 +268,8 @@ private:
   const char *skins[eFemonSkinMaxNumber];
   const char *themes[eFemonThemeMaxNumber];
   cFemonConfig data;
-  virtual void Setup(void);
+  cVector<const char*> help;
+  void Setup(void);
 protected:
   virtual eOSState ProcessKey(eKeys Key);
   virtual void Store(void);
@@ -285,6 +290,7 @@ cMenuFemonSetup::cMenuFemonSetup(void)
 
   themes[eFemonThemeClassic]       = tr("Classic");
   themes[eFemonThemeElchi]         = tr("Elchi");
+  themes[eFemonThemeSTTNG]         = tr("ST:TNG");
   themes[eFemonThemeDeepBlue]      = tr("DeepBlue");
   themes[eFemonThemeMoronimo]      = tr("Moronimo");
   themes[eFemonThemeEnigma]        = tr("Enigma");
@@ -301,24 +307,61 @@ void cMenuFemonSetup::Setup(void)
   int current = Current();
 
   Clear();
-  Add(new cMenuEditBoolItem(  tr("Hide main menu entry"),        &data.hidemenu));
-  Add(new cMenuEditStraItem(  tr("Default display mode"),        &data.displaymode,    eFemonModeMaxNumber, dispmodes));
-  Add(new cMenuEditStraItem(  trVDR("Setup.OSD$Skin"),           &data.skin,           eFemonSkinMaxNumber, skins));
-  Add(new cMenuEditStraItem(  trVDR("Setup.OSD$Theme"),          &data.theme,          eFemonThemeMaxNumber,themes));
-  Add(new cMenuEditBoolItem(  tr("Position"),                    &data.position,       trVDR("bottom"),     trVDR("top")));
-  Add(new cMenuEditIntItem(   trVDR("Setup.OSD$Height"),         &data.osdheight,      400,                 500));
-  Add(new cMenuEditIntItem(   tr("Horizontal offset"),           &data.osdoffset,      -50,                 50));
-  Add(new cMenuEditBoolItem(  tr("Show CA system"),              &data.showcasystem));
-  Add(new cMenuEditIntItem(   tr("Red limit [%]"),               &data.redlimit,       1,                   50));
-  Add(new cMenuEditIntItem(   tr("Green limit [%]"),             &data.greenlimit,     51,                  100));
-  Add(new cMenuEditIntItem(   tr("OSD update interval [0.1s]"),  &data.updateinterval, 1,                   100));
-  Add(new cMenuEditBoolItem(  tr("Analyze stream"),              &data.analyzestream));
-  if (femonConfig.analyzestream)
-     Add(new cMenuEditIntItem(tr("Calculation interval [0.1s]"), &data.calcinterval,   1,                   100));
-  Add(new cMenuEditBoolItem(  tr("Use SVDRP service"),           &data.usesvdrp));
+  help.Clear();
+
+  Add(new cMenuEditBoolItem(tr("Hide main menu entry"), &data.hidemenu));
+  help.Append(tr("Define whether the main menu entry is hidden."));
+
+  Add(new cMenuEditBoolItem(tr("Use single area (8bpp)"), &data.usesinglearea));
+  help.Append(tr("Define whether a single 8bpp OSD area is preferred.\n\nRequired by Truetype fonts and anti-aliasing."));
+
+  Add(new cMenuEditStraItem(tr("Default display mode"), &data.displaymode, eFemonModeMaxNumber, dispmodes));
+  help.Append(tr("Define the default display mode at startup."));
+
+  Add(new cMenuEditStraItem(trVDR("Setup.OSD$Skin"), &data.skin, eFemonSkinMaxNumber, skins));
+  help.Append(tr("Define the used OSD skin."));
+
+  Add(new cMenuEditStraItem(trVDR("Setup.OSD$Theme"), &data.theme, eFemonThemeMaxNumber,themes));
+  help.Append(tr("Define the used OSD theme."));
+
+  Add(new cMenuEditBoolItem(tr("Position"), &data.position, trVDR("bottom"), trVDR("top")));
+  help.Append(tr("Define the position of OSD."));
+
+  Add(new cMenuEditIntItem(trVDR("Setup.OSD$Height"), &data.osdheight, 400, 500));
+  help.Append(tr("Define the height of OSD."));
+
+  Add(new cMenuEditIntItem(tr("Horizontal offset"), &data.osdoffset, -50, 50));
+  help.Append(tr("Define the horizontal offset of OSD."));
+
+  Add(new cMenuEditBoolItem(tr("Show CA system"), &data.showcasystem));
+  help.Append(tr("Define whether the CA system is shown as text."));
+
+  Add(new cMenuEditIntItem(tr("Red limit [%]"), &data.redlimit, 1, 50));
+  help.Append(tr("Define a limit for red bar, which is used to indicate a bad signal."));
+
+  Add(new cMenuEditIntItem(tr("Green limit [%]"), &data.greenlimit, 51, 100));
+  help.Append(tr("Define a limit for green bar, which is used to indicate a good signal."));
+
+  Add(new cMenuEditIntItem(tr("OSD update interval [0.1s]"), &data.updateinterval, 1, 100));
+  help.Append(tr("Define an interval for OSD updates. The smaller interval generates higher CPU load."));
+
+  Add(new cMenuEditBoolItem(tr("Analyze stream"), &data.analyzestream));
+  help.Append(tr("Define whether the DVB stream is analyzed and bitrates calculated."));
+
+  if (femonConfig.analyzestream) {
+     Add(new cMenuEditIntItem(tr("Calculation interval [0.1s]"), &data.calcinterval, 1, 100));
+     help.Append(tr("Define an interval for calculation. The bigger interval generates more stable values."));
+     }
+
+  Add(new cMenuEditBoolItem(tr("Use SVDRP service"), &data.usesvdrp));
+  help.Append(tr("Define whether the SVDRP service is used in client/server setups."));
+
   if (data.usesvdrp) {
-     Add(new cMenuEditIntItem(tr("SVDRP service port"),          &data.svdrpport,      1,                   65535));
-     Add(new cMenuEditStrItem(tr("SVDRP service IP"),             data.svdrpip,        MaxSvdrpIp,          ".1234567890"));
+     Add(new cMenuEditIntItem(tr("SVDRP service port"), &data.svdrpport, 1, 65535));
+     help.Append(tr("Define the port number of SVDRP service."));
+
+     Add(new cMenuEditStrItem(tr("SVDRP service IP"), data.svdrpip, MaxSvdrpIp, ".1234567890"));
+     help.Append(tr("Define the IP address of SVDRP service."));
      }
 
   SetCurrent(Get(current));
@@ -330,6 +373,7 @@ void cMenuFemonSetup::Store(void)
   Dprintf("%s()\n", __PRETTY_FUNCTION__);
   femonConfig = data;
   SetupStore("HideMenu",       femonConfig.hidemenu);
+  SetupStore("UseSingleArea",  femonConfig.usesinglearea);
   SetupStore("DisplayMode",    femonConfig.displaymode);
   SetupStore("Skin",           femonConfig.skin);
   SetupStore("Theme",          femonConfig.theme);
@@ -354,9 +398,11 @@ eOSState cMenuFemonSetup::ProcessKey(eKeys Key)
 
   eOSState state = cMenuSetupPage::ProcessKey(Key);
 
-  if (Key != kNone && (data.analyzestream != oldAnalyzestream || data.usesvdrp != oldUsesvdrp)) {
+  if (Key != kNone && (data.analyzestream != oldAnalyzestream || data.usesvdrp != oldUsesvdrp))
      Setup();
-     }
+
+  if ((Key == kInfo) && (state == osUnknown) && (Current() < help.Size()))
+     return AddSubMenu(new cMenuText(cString::sprintf("%s - %s '%s'", tr("Help"), trVDR("Plugin"), PLUGIN_NAME_I18N), help[Current()]));
 
   return state;
 }
