@@ -25,6 +25,7 @@ struct cFemonConfig
 public:
   cFemonConfig(void);
   int hidemenu;
+  int usesinglearea;
   int displaymode;
   int skin;
   int theme;
@@ -55,6 +56,7 @@ enum eFemonThemes
 {
   eFemonThemeClassic,
   eFemonThemeElchi,
+  eFemonThemeSTTNG,
   eFemonThemeDeepBlue,
   eFemonThemeMoronimo,
   eFemonThemeEnigma,
